# Stew hash

This is a simple hashing library for python.

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [Support](#support)
- [Contributing](#contributing)

## Installation

Install the package using pip:

```sh
pip install stew-hash
```

## Usage

```python
from stew_hash import hash

# Hash a string
hash("Hello World") # 0x6dcd4ce23d88e2ee
```

## Support

Please [open an issue](https://github.com/apinanyogaratnam/stew-hash/issues/new) for support.

## Contributing

Please contribute using [Github Flow](https://guides.github.com/introduction/flow/). Create a branch, add commits, and [open a pull request](https://github.com/apinanyogaratnam/stew-hash/compare/).
